@@ -34,17 +34,10 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "debug.h"
 
 #include "parse.h"
-#include "parse-aux.h"
-#include "parse-paste.h"
 #include "parse-types.h"
 #include "lex.h"
-#include "mem.h"
+#include "hyper.h"
 #include "extent.h"
-#include "event.h"
-#include "display.h"
-#include "group.h"
-#include "scrollbar.h"
-#include "titlebar.h"
 
 #include "all_hyper_proto.H1"
 
@@ -58,7 +51,7 @@ static void start_scrolling(void);
 TextNode *curr_node;            /* current node being parsed. It is to be the
                                  * next one filled   */
 HashTable *gLinkHashTable;           /* the hash table of active link windows   */
-TextNode *cur_spadcom;          /* The current AXIOM command   */
+TextNode *cur_spadcom;          /* The current FRICAS command   */
 
 short int gParserMode;           /* Parser mode flag */
 short int gParserRegion;         /* Parser Region flag scrolling etc */
