@@ -89,24 +89,24 @@ Parts of the datatabase which was not pre-loaded is still
 \subsection{Database Files}
 
 Database files are very similar to KAF files except that there
-is an optimization (currently broken) which makes the first
+is an optimization which makes the first
 item a pair of two numbers. The first number in the pair is
 the offset of the key-value table, the second is a time stamp.
 If the time stamp in the database matches the time stamp in
 the image the database is not needed (since the internal hash
 tables already contain all of the information). When the database
-is built the time stamp is saved in both the gcl image and the
+is built the time stamp is saved in both the Lisp image and the
 database.
 |#
 
 ;;TTT 7/2/97
 ; Regarding the 'ancestors field for a category: At database build
-; time there exists a *ancestors-hash* hash table that gets filled
+; time there exists a |$ancestors_hash| hash table that gets filled
 ; with CATEGORY (not domain) ancestor information. This later provides
-; the information that goes into interp.daase This *ancestors-hash*
+; the information that goes into interp.daase This |$ancestors_hash|
 ; does not exist at normal runtime (it can be made by a call to
 ; genCategoryTable). Note that the ancestor information in
-; *ancestors-hash* (and hence interp.daase) involves #1, #2, etc
+; |$ancestors_hash| (and hence interp.daase) involves #1, #2, etc
 ; instead of R, Coef, etc. The latter thingies appear in all
 ; .NRLIB/index.KAF files. So we need to be careful when we )lib
 ; categories and update the ancestor info.
@@ -231,7 +231,7 @@ database.
 ; there are only a small number of categories that have default domains.
 ; rather than keep this slot in every domain we maintain a list here.
 
-(defvar *defaultdomain-list* '(
+(defvar |$defaultdomain_list| '(
   (|MultisetAggregate| |Multiset|)
   (|FunctionSpace| |Expression|)
   (|AlgebraicallyClosedFunctionSpace| |Expression|)
@@ -253,12 +253,12 @@ database.
 ; have category y?". this is answered by constructing a pair of
 ; (x . y) and doing an equal hash into this table.
 
-(defvar *operation-hash* nil "given an operation name, what are its modemaps?")
-(defvar *hasCategory-hash* nil "answers x has y category questions")
+(defvar |$operation_hash| nil "given an operation name, what are its modemaps?")
+(defvar |$has_category_hash| nil "answers x has y category questions")
 
-(defvar *miss* nil "print out cache misses on getdatabase calls")
+(defvar |$miss| nil "print out cache misses on getdatabase calls")
 
-(defvar *do-not-compress-databases* t)
+(defvar |$do_not_compress_databases| t)
 
    ; note that constructorcategory information need only be kept for
    ; items of type category. this will be fixed in the next iteration
@@ -275,35 +275,35 @@ database.
 
 ; this are the streams for the databases. they are always open.
 ; there is an optimization for speeding up system startup. if the
-; database is opened and the ..-stream-stamp* variable matches the
+; database is opened and the ..-stream-stamp variable matches the
 ; position information in the database then the database is NOT
 ; read in and is assumed to match the in-core version
 
-(defvar *compressvector* nil "a vector of things to compress in the databases")
-(defvar *compressVectorLength* 0 "length of the compress vector")
-(defvar *compress-stream* nil "an stream containing the compress vector")
-(defvar *compress-stream-stamp* 0 "*compress-stream* (position . time)")
+(defvar |$compress_vector| nil "a vector of things to compress in the databases")
+(defvar |$compress_vector_length| 0 "length of the compress vector")
+(defvar |$compress_stream| nil "an stream containing the compress vector")
+(defvar |$compress_stream_stamp| 0 "|$compress_stream| (position . time)")
 
-(defvar *interp-stream* nil "an open stream to the interpreter database")
-(defvar *interp-stream-stamp* 0 "*interp-stream* (position . time)")
+(defvar |$interp_stream| nil "an open stream to the interpreter database")
+(defvar |$interp_stream_stamp| 0 "|$interp_stream| (position . time)")
 
 ; this is indexed by operation, not constructor
-(defvar *operation-stream* nil "the stream to operation.daase")
-(defvar *operation-stream-stamp* 0 "*operation-stream* (position . time)")
+(defvar |$operation_stream| nil "the stream to operation.daase")
+(defvar |$operation_stream_stamp| 0 "|$operation_stream| (position . time)")
 
-(defvar *browse-stream* nil "an open stream to the browser database")
-(defvar *browse-stream-stamp* 0 "*browse-stream* (position . time)")
+(defvar |$browse_stream| nil "an open stream to the browser database")
+(defvar |$browse_stream_stamp| 0 "|$browse_stream| (position . time)")
 
 ; this is indexed by (domain . category)
-(defvar *category-stream* nil "an open stream to the category table")
-(defvar *category-stream-stamp* 0 "*category-stream* (position . time)")
+(defvar |$category_stream| nil "an open stream to the category table")
+(defvar |$category_stream_stamp| 0 "|$category_stream| (position . time)")
 
-(defvar *allconstructors* nil "a list of all the constructors in the system")
-(defvar *allOperations* nil "a list of all the operations in the system")
+(defvar |$all_constructors| nil "a list of all the constructors in the system")
+(defvar |$all_operations| nil "a list of all the operations in the system")
 
-(defvar *asharpflags* "-O -laxiom -Fasy -Flsp" "library compiler flags")
+(defvar |$asharp_flags| "-O -laxiom -Fasy -Flsp" "library compiler flags")
 
-(defun asharp (file &optional (flags *asharpflags*))
+(defun asharp (file &optional (flags |$asharp_flags|))
  "call the asharp compiler"
  (#| system::system |#
    obey
@@ -311,26 +311,26 @@ database.
     flags " " file)))
 
 (defun resethashtables ()
- "set all -hash* to clean values. used to clean up core before saving system"
- (setq *hascategory-hash* (make-hash-table :test #'equal))
- (setq *operation-hash* (make-hash-table))
- (setq *allconstructors* nil)
- (setq *compressvector* nil)
- (setq *compress-stream-stamp* '(0 . 0))
+ "set all *_hash to clean values. used to clean up core before saving system"
+ (setq |$has_category_hash| (make-hash-table :test #'equal))
+ (setq |$operation_hash| (make-hash-table))
+ (setq |$all_constructors| nil)
+ (setq |$compress_vector| nil)
+ (setq |$compress_stream_stamp| '(0 . 0))
  (|compressOpen|)
- (setq *interp-stream-stamp* '(0 . 0))
+ (setq |$interp_stream_stamp| '(0 . 0))
  (|interpOpen|)
- (setq *operation-stream-stamp* '(0 . 0))
+ (setq |$operation_stream_stamp| '(0 . 0))
  (|operationOpen|)
- (setq *browse-stream-stamp* '(0 . 0))
+ (setq |$browse_stream_stamp| '(0 . 0))
  (|browseOpen|)
- (setq *category-stream-stamp* '(0 . 0))
+ (setq |$category_stream_stamp| '(0 . 0))
  (|categoryOpen|) ;note: this depends on constructorform in browse.daase
  (initial-getdatabase)
- (close *interp-stream*)
- (close *operation-stream*)
- (close *category-stream*)
- (close *browse-stream*)
+ (close |$interp_stream|)
+ (close |$operation_stream|)
+ (close |$category_stream|)
+ (close |$browse_stream|)
 #+:GCL (LISP::gbc t)
 )
 
@@ -412,7 +412,7 @@ database.
  (dolist (con constr)
   (let ((c (concatenate 'string
              (|getEnv| "AXIOM") "/algebra/"
-             (string (getdatabase con 'abbreviation)) "." *lisp-bin-filetype*)))
+             (string (getdatabase con 'abbreviation)) "." |$lisp_bin_filetype|)))
     (format t "   preloading ~a.." c)
     (if (probe-file c)
      (progn
@@ -440,11 +440,10 @@ database.
 ;  )
 (defun |interpOpen| ()
  "open the interpreter database and hash the keys"
- (declare (special $spadroot))
  (let (constructors pos stamp dbstruct)
-  (setq *interp-stream* (open (DaaseName "interp.daase" nil)))
-  (setq stamp (read *interp-stream*))
-  (unless (equal stamp *interp-stream-stamp*)
+  (setq |$interp_stream| (open (DaaseName "interp.daase")))
+  (setq stamp (read |$interp_stream|))
+  (unless (equal stamp |$interp_stream_stamp|)
    (format t "   Re-reading interp.daase")
 
    ; Clean old data
@@ -453,15 +452,15 @@ database.
          (setf (get symbol 'database) nil))
       (when (get symbol 'abbreviationfor)
          (setf (get symbol 'abbreviationfor) nil)))
-   (setq *allconstructors* nil)
+   (setq |$all_constructors| nil)
 
-   (setq *interp-stream-stamp* stamp)
+   (setq |$interp_stream_stamp| stamp)
    (setq pos (car stamp))
-   (file-position *interp-stream* pos)
-   (setq constructors (read *interp-stream*))
+   (file-position |$interp_stream| pos)
+   (setq constructors (read |$interp_stream|))
    (dolist (item constructors)
     (setq item (unsqueeze item))
-    (setq *allconstructors* (adjoin (first item) *allconstructors*))
+    (setq |$all_constructors| (adjoin (first item) |$all_constructors|))
     (setq dbstruct (make-database))
     (setf (get (car item) 'database) dbstruct)
     (setf (database-operationalist dbstruct) (second item))
@@ -504,16 +503,15 @@ database.
 
 (defun |browseOpen| ()
  "open the constructor database and hash the keys"
- (declare (special $spadroot))
  (let (constructors pos stamp dbstruct)
-  (setq *browse-stream* (open (DaaseName "browse.daase" nil)))
-  (setq stamp (read *browse-stream*))
-  (unless (equal stamp *browse-stream-stamp*)
+  (setq |$browse_stream| (open (DaaseName "browse.daase")))
+  (setq stamp (read |$browse_stream|))
+  (unless (equal stamp |$browse_stream_stamp|)
    (format t "   Re-reading browse.daase")
-   (setq *browse-stream-stamp* stamp)
+   (setq |$browse_stream_stamp| stamp)
    (setq pos (car stamp))
-   (file-position *browse-stream* pos)
-   (setq constructors (read *browse-stream*))
+   (file-position |$browse_stream| pos)
+   (setq constructors (read |$browse_stream|))
    (dolist (item constructors)
     (setq item (unsqueeze item))
     (unless (setq dbstruct (get (car item) 'database))
@@ -523,7 +521,7 @@ database.
      (format t "get the database structure for this constructor and~%")
      (warn "will create a new one~%")
      (setf (get (car item) 'database) (setq dbstruct (make-database)))
-     (setq *allconstructors* (adjoin item *allconstructors*)))
+     (setq |$all_constructors| (adjoin item |$all_constructors|)))
     (setf (database-sourcefile dbstruct) (second item))
     (setf (database-constructorform dbstruct) (third item))
     (setf (database-documentation dbstruct) (fourth item))
@@ -533,58 +531,56 @@ database.
 
 (defun |categoryOpen| ()
  "open category.daase and hash the keys"
- (declare (special $spadroot))
  (let (pos keys stamp)
-  (setq *category-stream* (open (DaaseName "category.daase" nil)))
-  (setq stamp (read *category-stream*))
-  (unless (equal stamp *category-stream-stamp*)
+  (setq |$category_stream| (open (DaaseName "category.daase")))
+  (setq stamp (read |$category_stream|))
+  (unless (equal stamp |$category_stream_stamp|)
    (format t "   Re-reading category.daase")
-   (setq *category-stream-stamp* stamp)
+   (setq |$category_stream_stamp| stamp)
    (setq pos (car stamp))
-   (file-position *category-stream* pos)
-   (setq keys (read *category-stream*))
-   (setq *hasCategory-hash* (make-hash-table :test #'equal))
+   (file-position |$category_stream| pos)
+   (setq keys (read |$category_stream|))
+   (setq |$has_category_hash| (make-hash-table :test #'equal))
    (dolist (item keys)
     (setq item (unsqueeze item))
-    (setf (gethash (first item) *hasCategory-hash*) (second item))))
+    (setf (gethash (first item) |$has_category_hash|) (second item))))
   (format t "~&")))
 
 (defun |operationOpen| ()
  "read operation database and hash the keys"
- (declare (special $spadroot))
  (let (operations pos stamp)
-  (setq *operation-stream* (open (DaaseName "operation.daase" nil)))
-  (setq stamp (read *operation-stream*))
-  (unless (equal stamp *operation-stream-stamp*)
+  (setq |$operation_stream| (open (DaaseName "operation.daase")))
+  (setq stamp (read |$operation_stream|))
+  (unless (equal stamp |$operation_stream_stamp|)
    (format t "   Re-reading operation.daase")
-   (setq *operation-stream-stamp* stamp)
+   (setq |$operation_stream_stamp| stamp)
    (setq pos (car stamp))
-   (file-position *operation-stream* pos)
-   (setq operations (read *operation-stream*))
+   (file-position |$operation_stream| pos)
+   (setq operations (read |$operation_stream|))
 
    ; Clean old data
-   (setq *operation-hash* (make-hash-table))
-   (setq *allOperations* nil)
+   (setq |$operation_hash| (make-hash-table))
+   (setq |$all_operations| nil)
 
    (dolist (item operations)
     (setq item (unsqueeze item))
-    (setf (gethash (car item) *operation-hash*) (cdr item))))
+    (setf (gethash (car item) |$operation_hash|) (cdr item))))
   (format t "~&")))
 
 (defun addoperations (constructor oldmaps)
- "add ops from a )library domain to *operation-hash*"
- (declare (special *operation-hash*))
+ "add ops from a )library domain to |$operation_hash|"
+ (declare (special |$operation_hash|))
  (dolist (map oldmaps) ; out with the old
   (let (oldop op)
    (setq op (car map))
    (setq oldop (getdatabase op 'operation))
    (setq oldop (delete (cdr map) oldop :test #'equal))
-   (setf (gethash op *operation-hash*) oldop)))
+   (setf (gethash op |$operation_hash|) oldop)))
  (dolist (map (getdatabase constructor 'modemaps)) ; in with the new
   (let (op newmap)
    (setq op (car map))
    (setq newmap (getdatabase op 'operation))
-   (setf (gethash op *operation-hash*) (cons (cdr map) newmap)))))
+   (setf (gethash op |$operation_hash|) (cons (cdr map) newmap)))))
 
 (defun showdatabase (constructor)
  (format t "~&~a: ~a~%" 'constructorkind
@@ -659,8 +655,8 @@ database.
      (setf (get constructor 'abbreviationfor) nil)))))
 
 (defun getdatabase (constructor key)
- (declare (special $spadroot) (special *miss*))
- (when (eq *miss* t) (format t "getdatabase call: ~20a ~a~%" constructor key))
+ (declare (special $spadroot) (special |$miss|))
+ (when (eq |$miss| t) (format t "getdatabase call: ~20a ~a~%" constructor key))
  (let (data table stream ignore struct)
   (declare (ignore ignore))
   (when (or (symbolp constructor)
@@ -669,52 +665,52 @@ database.
 ; note that abbreviation, constructorkind and cosig are heavy hitters
 ; thus they occur first in the list of things to check
    (abbreviation
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
       (setq data (database-abbreviation struct))))
    (constructorkind
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-constructorkind struct))))
    (cosig
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-cosig struct))))
    (operation
-    (setq stream *operation-stream*)
-    (setq data (gethash constructor *operation-hash*)))
+    (setq stream |$operation_stream|)
+    (setq data (gethash constructor |$operation_hash|)))
    (constructormodemap
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-constructormodemap struct))))
    (constructorcategory
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-constructorcategory struct))
      (when (null data) ;domain or package then subfield of constructormodemap
       (setq data (cadar (getdatabase constructor 'constructormodemap))))))
    (operationalist
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-operationalist struct))))
    (modemaps
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-modemaps struct))))
    (hascategory
-    (setq table  *hasCategory-hash*)
-    (setq stream *category-stream*)
+    (setq table  |$has_category_hash|)
+    (setq stream |$category_stream|)
     (setq data (gethash constructor table)))
    (object
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-object struct))))
    (asharp?
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-object struct))))
    (niladic
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-niladic struct))))
    (constructor?
@@ -729,49 +725,49 @@ database.
    (constructor
     (when (setq data (get constructor 'abbreviationfor))))
    (defaultdomain
-    (setq data (cadr (assoc constructor *defaultdomain-list*))))
+    (setq data (cadr (assoc constructor |$defaultdomain_list|))))
    (ancestors
-    (setq stream *interp-stream*)
+    (setq stream |$interp_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-ancestors struct))))
    (sourcefile
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-sourcefile struct))))
    (constructorform
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-constructorform struct))))
    (constructorargs
     (setq data (cdr (getdatabase constructor 'constructorform))))
    (predicates
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-predicates struct))))
    (documentation
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-documentation struct))))
    (parents
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-parents struct))))
    (users
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-users struct))))
    (dependents
-    (setq stream *browse-stream*)
+    (setq stream |$browse_stream|)
     (when (setq struct (get constructor 'database))
      (setq data (database-dependents struct))))
    (otherwise  (warn "~%(GETDATABASE ~a ~a) failed~%" constructor key)))
   (when (numberp data)                 ;fetch the real data
-   (when *miss* (format t "getdatabase miss: ~20a ~a~%" constructor key))
+   (when |$miss| (format t "getdatabase miss: ~20a ~a~%" constructor key))
    (file-position stream data)
    (setq data (unsqueeze (read stream)))
    (case key ; cache the result of the database read
-    (operation           (setf (gethash constructor *operation-hash*) data))
-    (hascategory         (setf (gethash constructor *hascategory-hash*) data))
+    (operation           (setf (gethash constructor |$operation_hash|) data))
+    (hascategory         (setf (gethash constructor |$has_category_hash|) data))
     (constructorkind     (setf (database-constructorkind struct) data))
     (cosig               (setf (database-cosig struct) data))
     (constructormodemap  (setf (database-constructormodemap struct) data))
@@ -805,26 +801,13 @@ database.
        (setq data
              (if (string= (directory-namestring (car data)) "")
                  (concatenate 'string $spadroot "/algebra/" (car data)
-                                        "." *lisp-bin-filetype*)
+                                        "." |$lisp_bin_filetype|)
                (car data)))
       (when (and data (string= (directory-namestring data) ""))
        (setq data (concatenate 'string $spadroot "/algebra/" data
-                                          "." *lisp-bin-filetype*)))))))
+                                          "." |$lisp_bin_filetype|)))))))
   data))
 
-; )library top level command
-
-(defun |library| (args)
- (declare (special |$options|))
- (declare (special |$newConlist|))
- (setq original-directory (get-current-directory))
- (setq |$newConlist| nil)
- (localdatabase args |$options|)
-
- (|extendLocalLibdb| |$newConlist|)
- (chdir original-directory)
- (|terminateSystemCommand|))
-
 ; localdatabase tries to find files in the order of:
 ;  NRLIB/index.KAF
 ;  .asy
@@ -945,16 +928,16 @@ database.
          (let ((opname key)
                (modemap (car (LASSOC '|modemaps| alist))) )
            (setq oldmaps (getdatabase opname 'operation))
-           (setf (gethash opname *operation-hash*)
+           (setf (gethash opname |$operation_hash|)
                  (adjoin (subst asharp-name opname (cdr modemap))
                          oldmaps :test #'equal))
            (asharpMkAutoloadFunction object asharp-name))
        (when (if (null only) (not (eq key '%%)) (member key only))
-        (setq *allOperations* nil)        ; force this to recompute
+        (setq |$all_operations| nil)        ; force this to recompute
         (setq oldmaps (getdatabase key 'modemaps))
         (setq dbstruct (make-database))
         (setf (get key 'database) dbstruct)
-        (setq *allconstructors* (adjoin key *allconstructors*))
+        (setq |$all_constructors| (adjoin key |$all_constructors|))
         (setf (database-constructorform dbstruct)
          (fetchdata alist "constructorForm"))
         (setf (database-constructorkind dbstruct)
@@ -993,7 +976,7 @@ database.
                    (fetchdata alist "ancestors")))
          (if (eq kind '|domain|)
              (dolist (pair (cdr (assoc "ancestors" alist :test #'string=)))
-                     (setf (gethash (cons cname (caar pair)) *hascategory-hash*)
+                     (setf (gethash (cons cname (caar pair)) |$has_category_hash|)
                            (cdr pair))))
          (if |$InteractiveMode| (setq |$CategoryFrame| |$EmptyEnvironment|)))
         (setf (database-cosig dbstruct)
@@ -1026,10 +1009,10 @@ database.
    (setq key (car constructorform))
    (setq oldmaps (getdatabase key 'modemaps))
    (setq dbstruct (make-database))
-   (setq *allconstructors* (adjoin key *allconstructors*))
+   (setq |$all_constructors| (adjoin key |$all_constructors|))
    (setf (get key 'database) dbstruct) ; store the struct, side-effect it...
    (setf (database-constructorform dbstruct) constructorform)
-   (setq *allOperations* nil)   ; force this to recompute
+   (setq |$all_operations| nil)   ; force this to recompute
    (setf (database-object dbstruct) object)
    (setq abbrev
      (intern (pathname-name (first (last (pathname-directory object))))))
@@ -1080,15 +1063,14 @@ database.
 
 ; making new databases consists of:
 ;  1) reset all of the system hash tables
-;  *) set up Union, Record and Mapping
+;  1a) set up Union, Record and Mapping
 ;  2) map )library across all of the system files (fills the databases)
 ;  3) loading some normally autoloaded files
 ;  4) making some database entries that are computed (like ancestors)
 ;  5) writing out the databases
-;  6) write out 'warm' data to be loaded into the image at build time
 ; note that this process should be done in a clean image
 ; followed by a rebuild of the system image to include
-; the new index pointers (e.g. *interp-stream-stamp*)
+; the new index pointers (e.g. $interp_stream_stamp)
 ; the system will work without a rebuild but it needs to
 ; re-read the databases on startup. rebuilding the system
 ; will cache the information into the image and the databases
@@ -1101,29 +1083,28 @@ database.
  (labels (
     ;; these are types which have no library object associated with them.
     ;; we store some constructed data to make them perform like library
-    ;; objects, the *operationalist-hash* key entry is used by allConstructors
+    ;; objects
   (withSpecialConstructors ()
-   ; note: if item is not in *operationalist-hash* it will not be written
    ; Category
    (setf (get '|Category| 'database)
      (make-database :operationalist nil :niladic t))
-   (push '|Category| *allconstructors*)
+   (push '|Category| |$all_constructors|)
    ; UNION
    (setf (get '|Union| 'database)
      (make-database :operationalist nil :constructorkind '|domain|))
-   (push '|Union| *allconstructors*)
+   (push '|Union| |$all_constructors|)
    ; RECORD
    (setf (get '|Record| 'database)
     (make-database :operationalist nil :constructorkind '|domain|))
-   (push '|Record| *allconstructors*)
+   (push '|Record| |$all_constructors|)
    ; MAPPING
    (setf (get '|Mapping| 'database)
     (make-database :operationalist nil :constructorkind '|domain|))
-   (push '|Mapping| *allconstructors*)
+   (push '|Mapping| |$all_constructors|)
    ; ENUMERATION
    (setf (get '|Enumeration| 'database)
     (make-database :operationalist nil :constructorkind '|domain|))
-   (push '|Enumeration| *allconstructors*)
+   (push '|Enumeration| |$all_constructors|)
    )
   (final-name (root)
     (format nil "~a.daase" root))
@@ -1132,11 +1113,11 @@ database.
   (do-symbols (symbol)
    (when (get symbol 'database)
     (setf (get symbol 'database) nil)))
-  (setq *hascategory-hash* (make-hash-table :test #'equal))
-  (setq *operation-hash* (make-hash-table))
-  (setq *allconstructors* nil)
-  (setq *compressvector* nil)
-  (setq *allOperations* nil)
+  (setq |$has_category_hash| (make-hash-table :test #'equal))
+  (setq |$operation_hash| (make-hash-table))
+  (setq |$all_constructors| nil)
+  (setq |$compress_vector| nil)
+  (setq |$all_operations| nil)
   (withSpecialConstructors)
   (localdatabase nil
      (list (list '|dir| (namestring (truename "./")) ))
@@ -1149,23 +1130,13 @@ database.
                                                           dir)))))
                          'make-database))
 ;browse.daase
-  (|oldCompilerAutoloadOnceTrigger|)
-  (|browserAutoloadOnceTrigger|)
-#+:GCL    (|mkTopicHashTable|)
   (if br_data
-      (progn
-          (|buildLibdb|)
-          (|dbSplitLibdb|)
-          (|mkUsersHashTable|)
-          (|saveUsersHashTable|)
-          (|mkDependentsHashTable|)
-          (|saveDependentsHashTable|)))
-; (|buildGloss|)
+      (|save_browser_data|))
   (write-compress)
   (if br_data
       (write-browsedb))
   (write-operationdb)
- ; note: genCategoryTable creates a new *hascategory-hash* table
+ ; note: genCategoryTable creates a new |$has_category_hash| table
  ; this smashes the existing table and regenerates it.
  ; write-categorydb does getdatabase calls to write the new information
   (write-categorydb)
@@ -1176,15 +1147,14 @@ database.
                  (cons nil (mapcar #'|categoryForm?|
                                    (cddar (database-constructormodemap dbstruct)))))
            (when (and (|categoryForm?| con)
-                      (= (length (setq d (|domainsOf| (list con) NIL NIL))) 1))
+                      (= (length (setq d (|domainsOf| (list con) NIL))) 1))
                  (setq d (caar d))
                  (when (= (length d) (length (|getConstructorForm| con)))
                        (format t "   ~a has a default domain of ~a~%" con (car d))
                        (setf (database-defaultdomain dbstruct) (car d)))))))
-                                        ; note: genCategoryTable creates *ancestors-hash*. write-interpdb
-                                        ; does gethash calls into it rather than doing a getdatabase call.
+          ; note: genCategoryTable creates |$ancestors_hash|. write-interpdb
+          ; does gethash calls into it rather than doing a getdatabase call.
   (write-interpdb)
-#+:GCL  (write-warmdata)
   (|createInitializers|)
   (when (probe-file (final-name "compress"))
         (delete-file (final-name "compress")))
@@ -1204,7 +1174,7 @@ database.
   (rename-file "category.build"
                (final-name "category")))))
 
-(defun DaaseName (name erase?)
+(defun DaaseName (name)
  (let (daase filename)
   (declare (special $spadroot))
   (if (setq daase (|getEnv| "DAASE"))
@@ -1212,22 +1182,8 @@ database.
     (setq filename  (concatenate 'string daase "/algebra/" name))
     (format t "   Using local database ~a.." filename))
    (setq filename (concatenate 'string $spadroot "/algebra/" name)))
-  (when erase? (delete-file filename))
   filename))
 
-;; rewrite this so it works in mnt
-;;(defun DaaseName (name erase?)
-;; (let (daase filename)
-;;  (declare (special $spadroot))
-;;  (if (setq daase (|getEnv| "DAASE"))
-;;   (progn
-;;    (setq filename  (concatenate 'string daase "/algebra/" name))
-;;    (format t "   Using local database ~a.." filename))
-;;   (setq filename (concatenate 'string $spadroot "/algebra/" name)))
-;;  (when erase? (system::system (concatenate 'string "rm -f " filename)))
-;;  filename))
-
-
 ;; The compress database is special. It contains a list of symbols.
 ;; The character string name of a symbol in the other databases is
 ;; represented by a negative number. To get the real symbol back you
@@ -1237,26 +1193,25 @@ database.
 
 (defun |compressOpen| ()
  (let (lst stamp pos)
-  (declare (special $spadroot))
-  (setq *compress-stream*
-    (open (DaaseName "compress.daase"  nil) :direction :input))
-  (setq stamp (read *compress-stream*))
-  (unless (equal stamp *compress-stream-stamp*)
+  (setq |$compress_stream|
+    (open (DaaseName "compress.daase") :direction :input))
+  (setq stamp (read |$compress_stream|))
+  (unless (equal stamp |$compress_stream_stamp|)
    (format t "   Re-reading compress.daase")
-   (setq *compress-stream-stamp* stamp)
+   (setq |$compress_stream_stamp| stamp)
    (setq pos (car stamp))
-   (file-position *compress-stream* pos)
-   (setq lst (read *compress-stream*))
-   (setq *compressVectorLength* (car lst))
-   (setq *compressvector*
+   (file-position |$compress_stream| pos)
+   (setq lst (read |$compress_stream|))
+   (setq |$compress_vector_length| (car lst))
+   (setq |$compress_vector|
      (make-array (car lst) :initial-contents (cdr lst))))))
 
 (defun write-compress ()
  (let (compresslist masterpos out)
-  (close *compress-stream*)
+  (close |$compress_stream|)
   (setq out (open "compress.build" :direction :output :if-exists :supersede))
   (princ "                              " out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (setq masterpos (file-position out))
   (setq compresslist
         (append (|allConstructors|) (|allOperations|)))
@@ -1280,19 +1235,19 @@ database.
   (push '|Enumeration| compresslist)
   ;;; dummy zero element
   (push 0 compresslist)
-  (setq *compressVectorLength* (length compresslist))
-  (setq *compressvector*
-    (make-array *compressVectorLength* :initial-contents compresslist))
+  (setq |$compress_vector_length| (length compresslist))
+  (setq |$compress_vector|
+    (make-array |$compress_vector_length| :initial-contents compresslist))
   (print (cons (length compresslist) compresslist) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (file-position out 0)
   (print (cons masterpos (get-universal-time)) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (close out)))
 
 (defun write-interpdb ()
  "build interp.daase from hash tables"
- (declare (special $spadroot) (special *ancestors-hash*))
+ (declare (special |$ancestors_hash|))
  (let (opalistpos modemapspos cmodemappos master masterpos obj (*print-pretty* t)
         concategory categorypos kind niladic cosig abbrev defaultdomain
         ancestors ancestorspos out)
@@ -1302,7 +1257,7 @@ database.
   ;;  We reserve some space at the top of the file for the key-time pair
   ;;  We will overwrite these spaces just before we close the file.
   (princ "                              " out)
-  (finish-output out)
+  #+:GCL (force-output out)
 
   ;;  We loop across the list of constructors dumping the data and
   ;;  remembering the byte positions in a key-value pair table.
@@ -1337,7 +1292,7 @@ database.
     (setq cosig (database-cosig struct))
     (setq kind (database-constructorkind struct))
     (setq defaultdomain (database-defaultdomain struct))
-    (setq ancestors (squeeze (gethash constructor *ancestors-hash*))) ;cattable.boot
+    (setq ancestors (squeeze (gethash constructor |$ancestors_hash|)))
     (if ancestors
      (progn
       (setq ancestorspos (file-position out))
@@ -1346,26 +1301,25 @@ database.
     (push (list constructor opalistpos cmodemappos modemapspos
       obj categorypos niladic abbrev cosig kind defaultdomain
       ancestorspos) master)))
-  (finish-output out)
+  #+:GCL (force-output out)
   (setq masterpos (file-position out))
   (print (mapcar #'squeeze master) out)
-  (finish-output out)
+  #+:GCL (force-output out)
 
   ;; Write the timestamp
   (file-position out 0)
   (print (cons masterpos (get-universal-time)) out)
-  (finish-output out)
+  #+:GCL (force-output out)
 
   (close out)))
 
 (defun write-browsedb ()
  "make browse.daase from hash tables"
- (declare (special $spadroot))
  (let (master masterpos src formpos docpos attpos predpos (*print-pretty* t) out)
   (print "building browse.daase")
   (setq out (open "browse.build" :direction :output :if-exists :supersede))
   (princ "                              " out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (dolist (constructor (|allConstructors|))
    (let (struct)
     (setq struct (get constructor 'database))
@@ -1378,23 +1332,23 @@ database.
     (setq predpos (file-position out))
     (print (squeeze (database-predicates struct)) out)
     (push (list constructor src formpos docpos predpos) master)))
-  (finish-output out)
+  #+:GCL (force-output out)
   (setq masterpos (file-position out))
   (print (mapcar #'squeeze master) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (file-position out 0)
   (print (cons masterpos (get-universal-time)) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (close out)))
 
 (defun write-categorydb ()
- "make category.daase from scratch. contains the *hasCategory-hash* table"
+ "make category.daase from scratch. contains the |$has_category_hash| table"
  (let (out master pos (*print-pretty* t))
   (print "building category.daase")
   (|genCategoryTable|)
   (setq out (open "category.build" :direction :output :if-exists :supersede))
   (princ "                              " out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (maphash #'(lambda (key value)
     (if (or (null value) (eq value t))
      (setq pos value)
@@ -1402,29 +1356,29 @@ database.
       (setq pos (file-position out))
       (print (squeeze value) out)))
      (push (list key pos) master))
-     *hasCategory-hash*)
-  (finish-output out)
+     |$has_category_hash|)
+  #+:GCL (force-output out)
   (setq pos (file-position out))
   (print (mapcar #'squeeze master) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (file-position out 0)
   (print (cons pos (get-universal-time)) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (close out)))
 
 (defun unsqueeze (expr)
   (cond ((atom expr)
          (cond ((and (numberp expr) (< expr 0))
-                (svref *compressVector* (- expr)))
+                (svref |$compress_vector| (- expr)))
                (t expr)))
         (t (rplaca expr (unsqueeze (car expr)))
            (rplacd expr (unsqueeze (cdr expr)))
            expr)))
 
 (defun squeeze (expr)
-  (if *do-not-compress-databases*
+  (if |$do_not_compress_databases|
     expr
-    (let (leaves pos (bound (length *compressvector*)))
+    (let (leaves pos (bound (length |$compress_vector|)))
      (labels (
       (flat (expr)
        (when (and (numberp expr) (< expr 0))
@@ -1440,7 +1394,7 @@ database.
      (setq leaves nil)
      (flat expr)
      (dolist (leaf leaves)
-      (when (setq pos (position leaf *compressvector*))
+      (when (setq pos (position leaf |$compress_vector|))
         (nsubst (- pos) leaf expr)))
      expr))))
 
@@ -1449,39 +1403,30 @@ database.
   (print "building operation.daase")
   (setq out (open "operation.build" :direction :output :if-exists :supersede))
   (princ "                              " out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (maphash #'(lambda (key value)
    (setq pos (file-position out))
    (print (squeeze value) out)
    (push (cons key pos) master))
-   *operation-hash*)
-  (finish-output out)
+   |$operation_hash|)
+  #+:GCL (force-output out)
   (setq pos (file-position out))
   (print (mapcar #'squeeze master) out)
   (file-position out 0)
   (print (cons pos (get-universal-time)) out)
-  (finish-output out)
+  #+:GCL (force-output out)
   (close out)))
 
-(defun write-warmdata ()
- "write out information to be loaded into the image at build time"
- (declare (special |$topicHash|))
- (with-open-file (out "warm.data" :direction :output :if-exists :supersede)
-  (format out "(in-package \"BOOT\")~%")
-  (format out "(setq |$topicHash| (make-hash-table))~%")
-  (maphash #'(lambda (k v)
-   (format out "(setf (gethash '|~a| |$topicHash|) ~a)~%" k v)) |$topicHash|)))
-
 (defun |allConstructors| ()
- (declare (special *allconstructors*))
- *allconstructors*)
+ (declare (special |$all_constructors|))
+ |$all_constructors|)
 
 (defun |allOperations| ()
- (declare (special *allOperations*))
- (unless *allOperations*
-  (maphash #'(lambda (k v) (declare (ignore v)) (push k *allOperations*))
-    *operation-hash*))
- *allOperations*)
+ (declare (special |$all_operations|))
+ (unless |$all_operations|
+  (maphash #'(lambda (k v) (declare (ignore v)) (push k |$all_operations|))
+    |$operation_hash|))
+ |$all_operations|)
 
 ; the variable NOPfuncall is a funcall-able object that is a dummy
 ; initializer for libaxiom asharp domains.
@@ -1531,7 +1476,7 @@ database.
 ;  domain. the FIRST time this is done for the domain the autoloader
 ;  invokes the file object. every other time the domain already
 ;  exists.
-;(defvar *this-file* "no-file")
+;(defvar |$this_file| "no-file")
 
 (defmacro |CCall| (fun &rest args)
   (let ((ccc (gensym)) (cfun (gensym)) (cenv (gensym)))
@@ -1670,6 +1615,6 @@ database.
 ;    (declare (ignore libname))
 ;    (when (numberp hcode)
 ;         (setf (get bootname 'asharp-name)
-;               (cons (cons *this-file* asharpname)
+;               (cons (cons |$this_file| asharpname)
 ;                     (get bootname 'asharp-name)))
 ;         )))
