@@ -227,8 +227,8 @@
 (defmacro |CharNE|    (x y) `(CHAR/= (the |Char| ,x) (the |Char| ,y)))
 (defmacro |CharLower|   (x) `(the |Char| (CHAR-DOWNCASE (the |Char| ,x))))
 (defmacro |CharUpper|   (x) `(the |Char| (CHAR-UPCASE (the |Char| ,x))))
-(defmacro |CharOrd|     (x) `(CHAR-INT (the |Char| ,x)))
-(defmacro |CharNum|     (x) `(INT-CHAR (the |SInt| ,x)))
+(defmacro |CharOrd|     (x) `(CHAR-CODE (the |Char| ,x)))
+(defmacro |CharNum|     (x) `(CODE-CHAR (the |SInt| ,x)))
 
 (defmacro |SFlo0|        () 0.0s0)
 (defmacro |SFlo1|        () 1.0s0)
@@ -627,9 +627,9 @@
 ;;  ((|e1| |Env|)))
 (defmacro declare-prog (name-result params)
   `(proclaim '(ftype (function
-		      ,(mapcar #'cadr params)
-		      (values ,@(cdr name-result)))
-		     ,(car name-result))))
+                      ,(mapcar #'cadr params)
+                      (values ,@(cdr name-result)))
+                     ,(car name-result))))
 
 (defmacro declare-type (name type)
   `(proclaim '(type ,name ,type)))
@@ -808,13 +808,13 @@
 ;; given the name of a file (a string), return the name of the AXIOM-XL function
 ;; that initialises the file.
 (defun axiomxl-file-init-name (filename)
-  (intern (format nil "G-~a" (string-downcase filename)) 'foam-user))
+  (intern (format nil "G-~a" filename) 'foam-user))
 
 ;; given the name of the file, id name, and hashcode, return the
 ;; AXIOM-XL identifier for that object
 
 (defun axiomxl-global-name (file id hashcode)
-  (intern (format nil "G-~a_~a_~9,'0d" (string-downcase file) id hashcode) 'foam-user))
+  (intern (format nil "G-~a_~a_~9,'0d" file id hashcode) 'foam-user))
 
 ;; double float elementary functions
 (defmacro |sqrt| (x) `(sqrt ,x))
@@ -1049,3 +1049,8 @@
     (DEFCONST |G-axclique_integer_685864888| (cons #'H-integer nil))
     (DEFCONST |G-axclique_error_011667951| (cons #'H-error nil))
 )
+
+;; hashCombine for the code generated by the Aldor compiler
+
+(defun |SIntHashCombine| (x y)
+    (boot::|hashCombine| x y))
